@@ -18,12 +18,12 @@
 #ifndef GPARTED_GPARTED_CORE_H
 #define GPARTED_GPARTED_CORE_H
 
-#include "../include/BlockSpecial.h"
-#include "../include/FileSystem.h"
-#include "../include/Operation.h"
-#include "../include/Partition.h"
-#include "../include/PartitionLUKS.h"
-#include "../include/PartitionVector.h"
+#include "BlockSpecial.h"
+#include "FileSystem.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionLUKS.h"
+#include "PartitionVector.h"
 
 #include <parted/parted.h>
 #include <vector>
@@ -78,6 +78,7 @@ private:
 	//detectionstuff..
 	void set_thread_status_message( Glib::ustring msg ) ;
 	static Glib::ustring get_partition_path( PedPartition * lp_partition );
+	void set_device_from_disk( Device & device, const Glib::ustring & device_path );
 	void set_device_serial_number( Device & device );
 	void set_device_partitions( Device & device, PedDevice* lp_device, PedDisk* lp_disk ) ;
 	void set_device_one_partition( Device & device, PedDevice * lp_device, FILESYSTEM fstype,
@@ -106,7 +107,7 @@ private:
 
 	bool format( const Partition & partition, OperationDetail & operationdetail ) ;
 
-	bool Delete( const Partition & partition, OperationDetail & operationdetail ) ;
+	bool delete_partition( const Partition & partition, OperationDetail & operationdetail );
 
 	bool remove_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
 
@@ -114,7 +115,7 @@ private:
 
 	bool name_partition( const Partition & partition, OperationDetail & operationdetail );
 
-	bool change_uuid( const Partition & partition, OperationDetail & operation_detail ) ;
+	bool change_filesystem_uuid( const Partition & partition, OperationDetail & operation_detail );
 
 	bool resize_move( const Partition & partition_old,
 	                  Partition & partition_new,
@@ -136,44 +137,63 @@ private:
 	bool resize( const Partition & partition_old,
 		     const Partition & partition_new,
 		     OperationDetail & operationdetail ) ;
+	bool resize_encryption( const Partition & partition_old,
+	                        const Partition & partition_new,
+	                        OperationDetail & operationdetail );
+	bool resize_plain( const Partition & partition_old,
+	                   const Partition & partition_new,
+	                   OperationDetail & operationdetail );
 	bool resize_move_partition( const Partition & partition_old,
 			       	    const Partition & partition_new,
 				    OperationDetail & operationdetail ) ;
-	bool resize_filesystem( const Partition & partition_old,
-				const Partition & partition_new,
-				OperationDetail & operationdetail,
-				bool fill_partition = false ) ;
+	bool shrink_encryption( const Partition & partition_old,
+	                        const Partition & partition_new,
+	                        OperationDetail & operationdetail );
+	bool maximize_encryption( const Partition & partition,
+	                          OperationDetail & operationdetail );
+	bool shrink_filesystem( const Partition & partition_old,
+	                        const Partition & partition_new,
+	                        OperationDetail & operationdetail );
 	bool maximize_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
-				
+	bool recreate_linux_swap_filesystem( const Partition & partition,
+	                                     OperationDetail & operationdetail );
+	bool resize_filesystem_implement( const Partition & partition_old,
+	                                  const Partition & partition_new,
+	                                  OperationDetail & operationdetail );
+
 	bool copy( const Partition & partition_src,
-		   Partition & partition_dst,
-		   Byte_Value min_size,
-		   OperationDetail & operationdetail ) ; 
+	           Partition & partition_dst,
+	           OperationDetail & operationdetail );
 	bool copy_filesystem( const Partition & partition_src,
-			      const Partition & partition_dst,
-			      OperationDetail & operationdetail,
-			      bool cancel_safe );
-	bool copy_filesystem( const Partition & partition_src,
-			      const Partition & partition_dst,
-			      OperationDetail & operationdetail,
-			      Byte_Value & total_done,
-			      bool cancel_safe );
-	bool copy_filesystem( const Glib::ustring & src_device,
-			      const Glib::ustring & dst_device,
-			      Sector src_start,
-			      Sector dst_start,
-			      Byte_Value src_sector_size,
-			      Byte_Value dst_sector_size,
-			      Byte_Value src_length,
-			      OperationDetail & operationdetail,
-			      Byte_Value & total_done,
-			      bool cancel_safe ) ;
+	                      Partition & partition_dst,
+	                      OperationDetail & operationdetail );
+	bool copy_filesystem_internal( const Partition & partition_src,
+	                               const Partition & partition_dst,
+	                               OperationDetail & operationdetail,
+	                               bool cancel_safe );
+	bool copy_filesystem_internal( const Partition & partition_src,
+	                               const Partition & partition_dst,
+	                               OperationDetail & operationdetail,
+	                               Byte_Value & total_done,
+	                               bool cancel_safe );
+	bool copy_blocks( const Glib::ustring & src_device,
+	                  const Glib::ustring & dst_device,
+	                  Sector src_start,
+	                  Sector dst_start,
+	                  Byte_Value src_sector_size,
+	                  Byte_Value dst_sector_size,
+	                  Byte_Value src_length,
+	                  OperationDetail & operationdetail,
+	                  Byte_Value & total_done,
+	                  bool cancel_safe );
 	void rollback_transaction( const Partition & partition_src,
 				   const Partition & partition_dst,
 				   OperationDetail & operationdetail,
 				   Byte_Value total_done ) ;
 
 	bool check_repair_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
+	bool check_repair_maximize( const Partition & partition,
+	                            OperationDetail & operationdetail );
 
 	bool set_partition_type( const Partition & partition, OperationDetail & operationdetail ) ;
 
