@@ -23,8 +23,8 @@
 #ifndef GPARTED_PARTITION_H
 #define GPARTED_PARTITION_H
 
-#include "../include/Utils.h"
-#include "../include/PartitionVector.h"
+#include "Utils.h"
+#include "PartitionVector.h"
 
 #include <glibmm/ustring.h>
 
@@ -90,6 +90,7 @@ public:
 	virtual Sector get_sectors_unused() const;
 	virtual Sector get_sectors_unallocated() const;
 	void get_usage_triple( int imax, int & i1, int & i2, int & i3 ) const ;
+	virtual void resize( const Partition & new_size );
 
 	void Set_Unallocated( const Glib::ustring & device_path,
 	                      bool whole_device,
@@ -105,15 +106,15 @@ public:
 	Byte_Value get_byte_length() const ;
 	Sector get_sector_length() const ; 
 	Glib::ustring get_path() const ;
-	void add_mountpoint( const Glib::ustring & mountpoint, bool clear_mountpoints = false ) ;
-	void add_mountpoints( const std::vector<Glib::ustring> & mountpoints, bool clear_mountpoints = false ) ;
+	void add_mountpoint( const Glib::ustring & mountpoint );
+	void add_mountpoints( const std::vector<Glib::ustring> & mountpoints );
 	Glib::ustring get_mountpoint() const ; 
 	void clear_mountpoints() ;
 	std::vector<Glib::ustring> get_mountpoints() const ;
 	Sector get_sector() const ;
 	bool test_overlap( const Partition & partition ) const ;
 	bool filesystem_label_known() const;
-	virtual Glib::ustring get_filesystem_label() const;
+	Glib::ustring get_filesystem_label() const;
 	void set_filesystem_label( const Glib::ustring & filesystem_label );
 
 	// Message accessors.  Messages are stored locally and accessed globally.
@@ -131,6 +132,14 @@ public:
 	void append_messages( const std::vector<Glib::ustring> msgs )
 	                                { messages.insert( messages.end(), msgs.begin(), msgs.end() ); }
 
+	// Interface to return reference to the Partition object directly containing the
+	// file system.  Will be overridden in derived PartitionLUKS.
+	virtual const Partition & get_filesystem_partition() const     { return *this; };
+	virtual Partition & get_filesystem_partition()                 { return *this; };
+
+	virtual const Glib::ustring get_filesystem_string() const
+	                                { return Utils::get_filesystem_string( filesystem ); };
+
 	bool operator==( const Partition & partition ) const ;
 	bool operator!=( const Partition & partition ) const ;
 		
