@@ -24,7 +24,7 @@
 #ifndef GPARTED_UTILS_H
 #define GPARTED_UTILS_H
 
-#include "../include/i18n.h"
+#include "i18n.h"
 
 #include <gtkmm/label.h>
 #include <glibmm/ustring.h>
@@ -91,14 +91,15 @@ enum FILESYSTEM
 	// Recognised signatures but otherwise unsupported file system types
 	FS_BITLOCKER       = 25,
 	FS_GRUB2_CORE_IMG  = 26,
-	FS_LINUX_SWRAID    = 27,
-	FS_LINUX_SWSUSPEND = 28,
-	FS_REFS            = 29,
-	FS_ZFS             = 30,
+	FS_ISO9660         = 27,
+	FS_LINUX_SWRAID    = 28,
+	FS_LINUX_SWSUSPEND = 29,
+	FS_REFS            = 30,
+	FS_ZFS             = 31,
 
 	// Partition space usage colours
-	FS_USED            = 31,
-	FS_UNUSED          = 32
+	FS_USED            = 32,
+	FS_UNUSED          = 33
 } ;
 
 enum SIZE_UNIT
@@ -180,6 +181,8 @@ public:
 	static int get_max_partition_name_length( Glib::ustring & tabletype );
 	static int get_filesystem_label_maxlength( FILESYSTEM filesystem ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
+	static const Glib::ustring get_encrypted_string();
+	static const Glib::ustring get_filesystem_string( bool encrypted, FILESYSTEM fstype );
 	static const Glib::ustring get_filesystem_kernel_name( FILESYSTEM fstype );
 	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
 	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
