@@ -19,7 +19,8 @@
 #ifndef GPARTED_FAT16_H
 #define GPARTED_FAT16_H
 
-#include "../include/FileSystem.h"
+#include "FileSystem.h"
+#include "Partition.h"
 
 namespace GParted
 {
