@@ -15,8 +15,9 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../include/Utils.h"
-#include "../include/Dialog_Rescue_Data.h"
+#include "Utils.h"
+#include "Dialog_Rescue_Data.h"
+#include "Partition.h"
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/stock.h>
@@ -38,9 +39,9 @@ Dialog_Rescue_Data::Dialog_Rescue_Data()
 }
 
 //getters
-std::vector<Partition> Dialog_Rescue_Data::get_partitions()
+bool Dialog_Rescue_Data::found_partitions()
 {
-	return this->partitions;
+	return this->partitions.size() > 0;
 }
 
 // Draws the dialog
@@ -150,7 +151,7 @@ void Dialog_Rescue_Data::create_list_of_fs()
  * Callback function for "View" button */
 void Dialog_Rescue_Data::on_view_clicked(int nPart)
 {
-	Partition part=this->partitions[nPart];
+	const Partition & part = this->partitions[nPart];
 
 	Byte_Value initOffset=this->sector_size*part.sector_start;
 	Sector numSectors=part.sector_end-part.sector_start+1;
@@ -329,7 +330,6 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 		if(line.find("Primary partition")!=line.npos)
 		{
 			// Parameters of Partition::Set
-			Partition part;
 			Glib::ustring dev_path=this->device_path;
 			Glib::ustring part_path;
 			int part_num;
@@ -428,10 +428,10 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 				continue;
 			}
 
-			part.Set(dev_path, part_path, part_num,
-			         type, false, fs, sec_start, sec_end, sec_size, false, false);
-
-			this->partitions.push_back(part);
+			Partition * part = new Partition();
+			part->Set( dev_path, part_path, part_num,
+			           type, false, fs, sec_start, sec_end, sec_size, false, false );
+			this->partitions.push_back_adopt( part );
 		}
 	}
 }
