@@ -13,16 +13,16 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
- 
-#include "../include/FileSystem.h"
-#include "../include/GParted_Core.h"
+
+#include "FileSystem.h"
+#include "GParted_Core.h"
 
 #include <cerrno>
 #include <iostream>
 #include <gtkmm/main.h>
 #include <signal.h>
 #include <fcntl.h>
+#include <sigc++/slot.h>
 
 namespace GParted
 {
@@ -81,8 +81,35 @@ static void setup_child()
 
 int FileSystem::execute_command( const Glib::ustring & command, OperationDetail & operationdetail,
                                  ExecFlags flags )
+{
+	StreamSlot empty_stream_slot;
+	TimedSlot empty_timed_slot;
+	return execute_command_internal( command, operationdetail, flags, empty_stream_slot, empty_timed_slot );
+}
+
+int FileSystem::execute_command( const Glib::ustring & command, OperationDetail & operationdetail,
+                                 ExecFlags flags,
+                                 StreamSlot stream_progress_slot )
+{
+	TimedSlot empty_timed_slot;
+	return execute_command_internal( command, operationdetail, flags, stream_progress_slot, empty_timed_slot );
+}
+
+int FileSystem::execute_command( const Glib::ustring & command, OperationDetail & operationdetail,
+                                 ExecFlags flags,
+                                 TimedSlot timed_progress_slot )
+{
+	StreamSlot empty_stream_slot;
+	return execute_command_internal( command, operationdetail, flags, empty_stream_slot, timed_progress_slot );
+}
+
+int FileSystem::execute_command_internal( const Glib::ustring & command, OperationDetail & operationdetail,
+                                          ExecFlags flags,
+                                          StreamSlot stream_progress_slot,
+                                          TimedSlot timed_progress_slot )
 {
 	operationdetail.add_child( OperationDetail( command, STATUS_EXECUTE, FONT_BOLD_ITALIC ) );
+	OperationDetail & cmd_operationdetail = operationdetail.get_last_child();
 	Glib::Pid pid;
 	// set up pipes for capture
 	int out, err;
@@ -100,8 +127,7 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 			&err );
 	} catch (Glib::SpawnError &e) {
 		std::cerr << e.what() << std::endl;
-		operationdetail.get_last_child().add_child(
-			OperationDetail( e.what(), STATUS_ERROR, FONT_ITALIC ) );
+		cmd_operationdetail.add_child( OperationDetail( e.what(), STATUS_ERROR, FONT_ITALIC ) );
 		return Utils::get_failure_status( e );
 	}
 	fcntl( out, F_SETFL, O_NONBLOCK );
@@ -114,23 +140,29 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	PipeCapture errorcapture( err, error );
 	outputcapture.signal_eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
 	errorcapture.signal_eof.connect( sigc::mem_fun( *this, &FileSystem::execute_command_eof ) );
-	operationdetail.get_last_child().add_child(
-		OperationDetail( output, STATUS_NONE, FONT_ITALIC ) );
-	operationdetail.get_last_child().add_child(
-		OperationDetail( error, STATUS_NONE, FONT_ITALIC ) );
-	std::vector<OperationDetail*> &children = operationdetail.get_last_child().get_childs();
+	cmd_operationdetail.add_child( OperationDetail( output, STATUS_NONE, FONT_ITALIC ) );
+	cmd_operationdetail.add_child( OperationDetail( error, STATUS_NONE, FONT_ITALIC ) );
+	std::vector<OperationDetail*> &children = cmd_operationdetail.get_childs();
 	outputcapture.signal_update.connect( sigc::bind( sigc::ptr_fun( update_command_output ),
 	                                                 children[children.size() - 2],
 	                                                 &output ) );
 	errorcapture.signal_update.connect( sigc::bind( sigc::ptr_fun( update_command_output ),
 	                                                children[children.size() - 1],
 	                                                &error ) );
-	outputcapture.signal_update.connect( sigc::bind( sigc::mem_fun( *this, &FileSystem::update_command_progress ),
-	                                                 &operationdetail ) );
+	sigc::connection timed_conn;
+	if ( flags & EXEC_PROGRESS_STDOUT && ! stream_progress_slot.empty() )
+		// Call progress tracking callback when stdout updates
+		outputcapture.signal_update.connect( sigc::bind( stream_progress_slot, &cmd_operationdetail ) );
+	else if ( flags & EXEC_PROGRESS_STDERR && ! stream_progress_slot.empty() )
+		// Call progress tracking callback when stderr updates
+		errorcapture.signal_update.connect( sigc::bind( stream_progress_slot, &cmd_operationdetail ) );
+	else if ( flags & EXEC_PROGRESS_TIMED && ! timed_progress_slot.empty() )
+		// Call progress tracking callback every 500 ms
+		timed_conn = Glib::signal_timeout().connect( sigc::bind( timed_progress_slot, &cmd_operationdetail ), 500 );
 	outputcapture.connect_signal();
 	errorcapture.connect_signal();
 
-	operationdetail.get_last_child().signal_cancel.connect(
+	cmd_operationdetail.signal_cancel.connect(
 		sigc::bind(
 			sigc::ptr_fun( cancel_command ),
 			pid,
@@ -140,20 +172,18 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	if ( flags & EXEC_CHECK_STATUS )
 	{
 		if ( !exit_status )
-			operationdetail.get_last_child().set_status( STATUS_SUCCES );
+			cmd_operationdetail.set_status( STATUS_SUCCES );
 		else
-			operationdetail.get_last_child().set_status( STATUS_ERROR );
+			cmd_operationdetail.set_status( STATUS_ERROR );
 	}
 	close( out );
 	close( err );
+	if ( timed_conn.connected() )
+		timed_conn.disconnect();
+	cmd_operationdetail.stop_progressbar();
 	return exit_status;
 }
 
-void FileSystem::update_command_progress( OperationDetail *operationdetail )
-{
-	signal_progress.emit( operationdetail );
-}
-
 void FileSystem::set_status( OperationDetail & operationdetail, bool success )
 {
 	operationdetail.get_last_child().set_status( success ? STATUS_SUCCES : STATUS_ERROR );
