@@ -14,8 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#include "../include/Partition.h"
+
+#include "Partition.h"
 
 namespace GParted
 {
@@ -163,6 +163,20 @@ Sector Partition::get_sectors_unallocated() const
 		return sectors_unallocated ;
 }
 
+// Update size, position and FS usage from new_size.
+void Partition::resize( const Partition & new_size )
+{
+	sector_start      = new_size.sector_start;
+	sector_end        = new_size.sector_end;
+	alignment         = new_size.alignment;
+	free_space_before = new_size.free_space_before;
+	strict_start      = new_size.strict_start;
+
+	Sector fs_size   = new_size.sectors_used + new_size.sectors_unused;
+	Sector fs_unused = fs_size - new_size.sectors_used;
+	set_sector_usage( fs_size, fs_unused );
+}
+
 void Partition::Set_Unallocated( const Glib::ustring & device_path,
                                  bool whole_device,
                                  Sector sector_start,
@@ -308,19 +322,13 @@ void Partition::get_usage_triple_helper( Sector stot, Sector s1, Sector s2, Sect
 	}
 }
 
-void Partition::add_mountpoint( const Glib::ustring & mountpoint, bool clear_mountpoints )
+void Partition::add_mountpoint( const Glib::ustring & mountpoint )
 {
-	if ( clear_mountpoints )
-		this ->mountpoints .clear() ;
-
 	this ->mountpoints .push_back( mountpoint ) ;
 }
 
-void Partition::add_mountpoints( const std::vector<Glib::ustring> & mountpoints, bool clear_mountpoints ) 
+void Partition::add_mountpoints( const std::vector<Glib::ustring> & mountpoints )
 {
-	if ( clear_mountpoints )
-		this ->mountpoints .clear() ;
-
 	this ->mountpoints .insert( this ->mountpoints .end(), mountpoints .begin(), mountpoints .end() ) ;
 }
 
