@@ -14,16 +14,17 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#include "../include/TreeView_Detail.h"
-#include "../include/Partition.h"
-#include "../include/PartitionLUKS.h"
-#include "../include/PartitionVector.h"
+
+#include "TreeView_Detail.h"
+#include "Partition.h"
+#include "PartitionLUKS.h"
+#include "PartitionVector.h"
 
 #include <vector>
 #include <gtkmm/cellrenderer.h>
 #include <gtkmm/cellrenderertext.h>
 #include <pangomm/layout.h>
+#include <glibmm/ustring.h>
 
 namespace GParted
 { 
@@ -82,14 +83,17 @@ TreeView_Detail::TreeView_Detail()
 
 void TreeView_Detail::load_partitions( const PartitionVector & partitions )
 {
-	bool mountpoints = false, labels = false, names = false;
+	bool show_names       = false;
+	bool show_mountpoints = false;
+	bool show_labels      = false;
+
 	treestore_detail ->clear() ;
 
-	load_partitions( partitions, mountpoints, labels, names );
+	load_partitions( partitions, show_names, show_mountpoints, show_labels );
 
-	get_column( 1 )->set_visible( names );
-	get_column( 3 )->set_visible( mountpoints );
-	get_column( 4 )->set_visible( labels );
+	get_column( 1 )->set_visible( show_names );
+	get_column( 3 )->set_visible( show_mountpoints );
+	get_column( 4 )->set_visible( show_labels );
 
 	columns_autosize();
 	expand_all() ;
@@ -108,28 +112,19 @@ void TreeView_Detail::clear()
 }
 
 void TreeView_Detail::load_partitions( const PartitionVector & partitions,
-                                       bool & mountpoints,
-                                       bool & labels,
-                                       bool & names,
+                                       bool & show_names,
+                                       bool & show_mountpoints,
+                                       bool & show_labels,
                                        const Gtk::TreeRow & parent_row )
 {
 	Gtk::TreeRow row ;
 	for ( unsigned int i = 0 ; i < partitions .size() ; i++ ) 
 	{	
 		row = parent_row ? *( treestore_detail ->append( parent_row .children() ) ) : *( treestore_detail ->append() ) ;
-		create_row( row, partitions[ i ] );
-		
+		create_row( row, partitions[i], show_names, show_mountpoints, show_labels );
+
 		if ( partitions[ i ] .type == GParted::TYPE_EXTENDED )
-			load_partitions( partitions[i].logicals, mountpoints, labels, names, row );
-
-		if ( partitions[ i ] .get_mountpoints() .size() )
-			mountpoints = true ;
-					
-		if ( ! partitions[ i ].get_filesystem_label().empty() )
-			labels = true ;
-
-		if ( ! partitions[i].name.empty() )
-			names = true;
+			load_partitions( partitions[i].logicals, show_names, show_mountpoints, show_labels, row );
 	}
 }
 
@@ -154,9 +149,14 @@ bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows,
 	return false ;
 }
 
-void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition & partition )
+void TreeView_Detail::create_row( const Gtk::TreeRow & treerow,
+                                  const Partition & partition,
+                                  bool & show_names,
+                                  bool & show_mountpoints,
+                                  bool & show_labels )
 {
-	if ( partition .busy )
+	const Partition & filesystem_ptn = partition.get_filesystem_partition();
+	if ( filesystem_ptn.busy )
 		treerow[ treeview_detail_columns .icon1 ] = 
 			render_icon( Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON );
 	
@@ -179,42 +179,25 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 
 	// name
 	treerow[treeview_detail_columns.name] = partition.name;
+	if ( ! partition.name.empty() )
+		show_names = true;
 
-	if ( partition.filesystem == FS_LUKS && partition.busy )
-	{
-		const Partition & encrypted = dynamic_cast<const PartitionLUKS *>( &partition )->get_encrypted();
+	// file system
+	treerow[treeview_detail_columns.color] = Utils::get_color_as_pixbuf( filesystem_ptn.filesystem, 16, 16 );
+	treerow[treeview_detail_columns.filesystem] = partition.get_filesystem_string();
 
-		// file system
-		treerow[treeview_detail_columns.color] = Utils::get_color_as_pixbuf( encrypted.filesystem, 16, 16 );
-		/* TO TRANSLATORS: means that this is an encrypted file system */
-		treerow[treeview_detail_columns.filesystem] = "[" + Glib::ustring( _("Encrypted") ) + "] " +
-		                                              Utils::get_filesystem_string( encrypted.filesystem );
-
-		// mount point
-		treerow[treeview_detail_columns.mountpoint] = Glib::build_path( ", ", encrypted.get_mountpoints() );
-	}
-	else if ( partition.filesystem == FS_LUKS && ! partition.busy )
-	{
-		// file system
-		treerow[treeview_detail_columns.color] = Utils::get_color_as_pixbuf( partition.filesystem, 16, 16 );
-		treerow[treeview_detail_columns.filesystem] = "[" + Glib::ustring( _("Encrypted") ) + "]";
-
-		// mount point
-		treerow[treeview_detail_columns.mountpoint] = Glib::build_path( ", ", partition.get_mountpoints() );
-	}
-	else
-	{
-		// file system
-		treerow[treeview_detail_columns.color] = Utils::get_color_as_pixbuf( partition.filesystem, 16, 16 );
-		treerow[treeview_detail_columns.filesystem] = Utils::get_filesystem_string( partition.filesystem );
-
-		// mount point
-		treerow[treeview_detail_columns.mountpoint] = Glib::build_path( ", ", partition.get_mountpoints() );
-	}
+	// mount point
+	std::vector<Glib::ustring> temp_mountpoints = filesystem_ptn.get_mountpoints();
+	treerow[treeview_detail_columns.mountpoint] = Glib::build_path( ", ", temp_mountpoints );
+	if ( ! temp_mountpoints.empty() )
+		show_mountpoints = true;
 
 	//label
-	treerow[ treeview_detail_columns .label ] = partition.get_filesystem_label();
-		
+	Glib::ustring temp_filesystem_label = filesystem_ptn.get_filesystem_label();
+	treerow[treeview_detail_columns.label] = temp_filesystem_label;
+	if ( ! temp_filesystem_label.empty() )
+		show_labels = true;
+
 	//size
 	treerow[ treeview_detail_columns .size ] = Utils::format_size( partition .get_sector_length(), partition .sector_size ) ;
 	
