@@ -14,17 +14,15 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-
-#include "../include/f2fs.h"
+#include "f2fs.h"
+#include "Partition.h"
 
 namespace GParted
 {
 
 FS f2fs::get_filesystem_support()
 {
-	FS fs ;
-
-	fs .filesystem = FS_F2FS ;
+	FS fs( FS_F2FS );
 
 	fs .busy = FS::GPARTED ;
 
