@@ -14,10 +14,9 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
- 
-#include "../include/fat16.h"
-#include "../include/Partition.h"
+
+#include "fat16.h"
+#include "Partition.h"
 
 /*****
 //For some reason unknown, this works without these include statements.
@@ -266,7 +265,7 @@ const Glib::ustring fat16::sanitize_label( const Glib::ustring &label ) const
 	// [2] Replicated in Wikikedia: label (command)
 	//     https://en.wikipedia.org/wiki/Label_%28command%29
 	Glib::ustring prohibited_chars( "*?.,;:/\\|+=<>[]" );
-	for ( unsigned int i = 0 ; i < label.size() ; i ++ )
+	for ( unsigned int i = 0 ; i < uppercase_label.size() ; i ++ )
 		if ( prohibited_chars.find( uppercase_label[i] ) == Glib::ustring::npos )
 			new_label.push_back( uppercase_label[i] );
 
